==> haskell-hspec-wai-json-0.11.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-A4tXSjMOobvEEvAWuhKHDs
key:                  hspec-wai-json-0.11.0-A4tXSjMOobvEEvAWuhKHDs
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  ff4c4b52ad1a5d26a4d30becb6655614
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-8.10.2/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hspec-wai-json-0.11.0
hs-libraries:         HShspec-wai-json-0.11.0-A4tXSjMOobvEEvAWuhKHDs
depends:
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t
    aeson-qq-0.8.3-SqmPrLLSJp4mBTTukWLy4 base-4.14.1.0
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-7Aj4g2iZgZR4Q8sB4UJ8do
    hspec-wai-0.11.1-LwdN64SewvOCZWitOxsTkJ template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-3DYWI58Zqgr7t0EoEzFxCc
key:                  hspec-wai-json-0.11.0-3DYWI58Zqgr7t0EoEzFxCc
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  b01a476d000646b9c17355a8de9967af
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hspec-wai-json-0.11.0
hs-libraries:         HShspec-wai-json-0.11.0-3DYWI58Zqgr7t0EoEzFxCc
depends:
    aeson-1.5.4.1-2CAWo3gcbCSCjWuZ8mOFKc
    aeson-qq-0.8.3-6xwvhzvAwKhJhcoJfSikiU base-4.14.1.0
    bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L0gITQjreIr3hbLO2ORRC8
    hspec-wai-0.11.1-Jc52Ua1vHF949whnNRg8Xx template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
